<?php

namespace Modules\Fornecimento\Modules\AutorizacaoFornecimento\Services;

use Services\FileService;

class AcompanhamentoAprovacaoService
{
    protected $environment;
    protected $service;

    public function __construct($environment, $supUtilities, $newCode, FileService $service)
    {
        $this->environment  = $environment;
        $this->supUtilities = $supUtilities;
        $this->newCode      = $newCode;
        $this->service      = $service;
    }

    public function salvaAnexoGrid($row)
    {
        try {
            $row['NMPATHANEXO'] = $this->service->uploudFile($row['ANEXO'][0]);
            $params = [
                'NRANEXOLANCAF'  => $this->newCode->getCodeByTableName('ANEXOLANCAF', $this->environment->getNrOrg()),
                'NRAUTOFORN'     => $row['NRAUTOFORN'],
                'CDFILDEST'      => $row['CDFILDEST'],
                'CDTELA'         => 'APPROVE',
                'DTANEXOLANCAF'  => $row['DTANEXOLANCAF'],
                'NMANEXOLANCAF'  => $row['ANEXO'][0]["name"],
                'NMPATHANEXO'    => $row['NMPATHANEXO'],
                'DSANEXOLANCAF'  => isset($row['DSANEXOLANCAF']) ? $row['DSANEXOLANCAF'] : null,
                'DSINFOANEXO'    => $this->getFileInfo($row),
                'NRORG'          => $this->environment->getNrOrg(),
                'NRORGINCLUSAO'  => $this->environment->getNrOrg(),
                'CDOPERINCLUSAO' => $this->environment->getCdOperador(),
                'NRORGULTATU'    => $this->environment->getNrOrg(),
                'CDOPERULTATU'   => $this->environment->getCdOperador(),
            ];

            $sql = "INSERT INTO ANEXOLANCAF ( NRANEXOLANCAF, CDTELA, DTANEXOLANCAF, NMANEXOLANCAF, NMPATHANEXO, DSANEXOLANCAF, DSINFOANEXO, NRAUTOFORN, CDFILDEST, NRORG, DTINCLUSAO, NRORGINCLUSAO, CDOPERINCLUSAO, DTULTATU, NRORGULTATU, CDOPERULTATU ) VALUES ( :NRANEXOLANCAF, :CDTELA, :DTANEXOLANCAF, :NMANEXOLANCAF, :NMPATHANEXO, :DSANEXOLANCAF, :DSINFOANEXO, :NRAUTOFORN, :CDFILDEST, :NRORG, SYSDATE, :NRORGINCLUSAO, :CDOPERINCLUSAO, SYSDATE, :NRORGULTATU, :CDOPERULTATU )";

            $std = $this->supUtilities->crud($sql, $params);
        } catch (\Exception $e) {
            throw $e;
        }
    }

    public function deleteAnexoGrid($rows)
    {
        try {
            foreach ($rows as $row) {
                $this->service->deleteFile($row);

                $params = [
                    'NRANEXOLANCAF' => $row['NRANEXOLANCAF'],
                    'CDTELA'        => $row['CDTELA']
                ];

                $sql = "DELETE FROM ANEXOLANCAF WHERE NRANEXOLANCAF = :NRANEXOLANCAF AND CDTELA = :CDTELA";

                $this->supUtilities->crud($sql, $params);
            }
        } catch (\Exception $e) {
            throw $e;
        }
    }

    private function getFileInfo($row)
    {
        return $row['ANEXO'][0]["lastModified"] . '_' . $row['ANEXO'][0]["lastModifiedDate"] . '_' .
            $row['ANEXO'][0]["webkitRelativePath"] . '_' . $row['ANEXO'][0]["type"] . '_' .
            $row['ANEXO'][0]["size"] . '_' . $row['ANEXO'][0]["name"];
    }
}
