CREATE OR REPLACE PROCEDURE DASHBOARD_FIS_COUNT
AS
   V_IDAPURA VARCHAR2(01);
BEGIN

   DELETE FROM FISPDCCONT;

   /*PREENCHE A TABELA APENAS PARA CLIENTES QUE REALIZARAM A APURAO DO ICMS PELO MENOS NOS LTIMOS 3 MESES*/
   BEGIN
      SELECT MAX('S')
        INTO V_IDAPURA
        FROM MAPAAPURAC
       WHERE CDIMPOSTO    IN ('00','50','60')
         AND IDBLOQMAPAPU IS NOT NULL
         AND DTFIMPERIODO BETWEEN ADD_MONTHS(LAST_DAY(SYSDATE),-3) AND (SYSDATE);
   EXCEPTION
      WHEN NO_DATA_FOUND THEN
         V_IDAPURA := 'N';
   END;

   IF NVL(V_IDAPURA,'N') = 'S' THEN
      /*INSERE OS DADOS REFERENTES AS VENDAS NFC-E E SAT PENDENTES DE APROVAO OU COM ERRO*/
      FOR C_COUNT_VENDA IN (SELECT DISTINCT V.NRORG, V.CDEMPRESA, V.CDFILIAL, V.CDCAIXA, V.DTENTRVENDA, V.IDAPROVACAONFCE, V.IDTPEMISVEND
                              FROM VENDA V, FILIAL F, PARAVEND PA, PARAMFISCAL PF
                             WHERE V.CDEMPRESA    = F.CDEMPRESA
                               AND V.CDFILIAL     = F.CDFILIAL
                               AND V.IDTPEMISVEND IN ('N','S')
                               AND V.IDTPAMBNFCE  = '1'
                               AND V.IDSTATUSNFCE = 'A'
                               AND V.IDSITUVENDA  = 'O'
                               AND V.IDAPROVACAONFCE IN ('P','E')
                               AND V.DTENTRVENDA  >= PF.DTININFFORPER
                               AND V.CDFILIAL     = PA.CDFILIAL
                               AND F.CDFILIAL     = PA.CDFILIAL) LOOP
         INSERT INTO FISPDCCONT
            (IDFISPDCCONT, NRORG,CDEMPRESA, DTFISPDCCONT)
         VALUES
            ('CUPOM_VENDAS', C_COUNT_VENDA.NRORG, C_COUNT_VENDA.CDEMPRESA, C_COUNT_VENDA.DTENTRVENDA);
      END LOOP;

      /*INSERE OS DADOS REFERENTES AS VENDAS REDUO Z PENDENTES DE APROVAO OU COM ERRO*/
      FOR C_COUNT_REDZ IN (SELECT DISTINCT V.NRORG, V.CDFILIAL, V.CDEMPRESA, V.DTENTRVENDA, V.IDAPROVACAONFCE, V.CDCAIXA
                             FROM REDUCAOZ R, VENDA V, PARAMFISCAL PF
                            WHERE R.IDSTATUS    <> 'A'
                              AND R.DTREDUCAOZ  = V.DTENTRVENDA
                              AND R.CDFILIAL    = V.CDFILIAL
                              AND R.CDCAIXA     = V.CDCAIXA
                              AND NVL(V.IDTPEMISVEND,'E') = 'E'
                              AND V.IDSITUVENDA = 'O'
                              AND V.DTENTRVENDA >= PF.DTININFFORPER) LOOP
         INSERT INTO FISPDCCONT
            (IDFISPDCCONT, NRORG,CDEMPRESA, DTFISPDCCONT)
         VALUES
            ('CUPOM_VENDAS', C_COUNT_REDZ.NRORG, C_COUNT_REDZ.CDEMPRESA, C_COUNT_REDZ.DTENTRVENDA);
      END LOOP;

      /*INSERE OS DADOS REFERENTES AS NOTAS FISCAIS PENDENTES DE APROVAO*/
      FOR C_COUNT_NOTA IN (SELECT DISTINCT  N.NRORG, N.CDEMPRESA, N.CDFILIAL, N.NRLANCTONF, DECODE(IDENTRSAIDOP,'E',DTENTRSAID,DTEMISSAO) AS DATA
                             FROM NOTAFISCAL N, IMPOSTONF I, PARAMFISCAL P
                            WHERE N.IDSTATUS   = 'P'
                              AND N.IDSTATUSNFE <> 'D'
                              AND I.CDFILIAL   = N.CDFILIAL
                              AND I.NRLANCTONF = N.NRLANCTONF
                              AND DECODE(IDENTRSAIDOP,'E',DTENTRSAID,DTEMISSAO) >= P.DTININFFORPER) LOOP
         INSERT INTO FISPDCCONT
            (IDFISPDCCONT, NRORG,CDEMPRESA, DTFISPDCCONT)
         VALUES
            ('NOTA_FISCAL', C_COUNT_NOTA.NRORG, C_COUNT_NOTA.CDEMPRESA, C_COUNT_NOTA.DATA);
      END LOOP;
   END IF;
   
END;
/